-- by modelleicher
-- www.schwabenmodding.bplaced.net
-- edit RivalBomb, an Fendt Farmer 310 LSA angepasst

Fendt310Animations = {};

function Fendt310Animations.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function Fendt310Animations:load(xmlFile)
	-- Uhr / clock
	self.uhrZeigerKlein = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.Uhr#zeigerKleinIndex"));
	self.uhrZeigerGross = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.Uhr#zeigerGrossIndex"));
	
	-- Allradhebel
	self.allradHebel = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.AllradHebel#index"));
	self.allradHebelMaxTrans = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Fendt310Animations.Allradhebel#maxYTrans"));
	
	-- Zapfwelle
	self.zapfwelle = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.Zapfwelle#index"));
	self.zapfwelleMaxRot = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.Fendt310Animations.Zapfwelle#maxRot"));
	
	-- Zustzliche Blinkleuchten in den Armaturen bei angehngten Anhngern / additional lights for turninglights at the dashboard if trailers attached
	self.blinkerLeuchte1L = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.BlinkerLeuchten#leuchte1L"));
	self.blinkerLeuchte2L = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.BlinkerLeuchten#leuchte2L"));
	self.blinkerLeuchte1R = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.BlinkerLeuchten#leuchte1R"));
	self.blinkerLeuchte2R = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.BlinkerLeuchten#leuchte2R"));
	self.hasAttachedTrailers = 0;
	setVisibility(self.blinkerLeuchte1R, false);
	setVisibility(self.blinkerLeuchte2R, false);
	setVisibility(self.blinkerLeuchte1L, false);
	setVisibility(self.blinkerLeuchte2L, false);
	
	self.blinkerHebel = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.Fendt310Animations.BlinkerHebel#index"));
	self.blinkerHebelLeftRot = getXMLFloat(xmlFile, "vehicle.Fendt310Animations.BlinkerHebel#linksRot");
	self.blinkerHebelRightRot = getXMLFloat(xmlFile, "vehicle.Fendt310Animations.BlinkerHebel#rechtsRot");
end;
function Fendt310Animations:delete()
end;
function Fendt310Animations:mouseEvent(posX, posY, isDown, isUp, button)
end;
function Fendt310Animations:keyEvent(unicode, sym, modifier, isDown)
end;

function Fendt310Animations:updateTick(dt)
	-- Zustzliche Blinkleuchten in den Armaturen bei angehngten Anhngern / additional lights for turninglights at the dashboard if trailers attached
	if table.getn(self.attachedImplements) > 0 or self.hasAttachedTrailers > 0 then
		self.hasAttachedTrailers = 0;
		for i=1, table.getn(self.attachedImplements) do  
			if self.attachedImplements[i].object.lastFillDelta ~= nil then -- "catch" all trailers 
				self.hasAttachedTrailers = 	self.hasAttachedTrailers +1;
			elseif self.attachedImplements[i].object.isSprayerFilling ~= nil and self.attachedImplements[i].object.wheels[1] ~= nil then -- "catch" manure and dung spreader with wheels --> "trailers", too
				self.hasAttachedTrailers = 	self.hasAttachedTrailers +1;
			end;
			if table.getn(self.attachedImplements[i].object.attachedImplements) > 0 then -- maybe the trailer has also attached a trailer.. 
				for r=1, table.getn(self.attachedImplements[i].object.attachedImplements) do
					if self.attachedImplements[i].object.attachedImplements[r].object.lastFillDelta ~= nil then -- "catch" attached trailer at the trailer here
						self.hasAttachedTrailers = 	self.hasAttachedTrailers +1;
					end;
				end;
			end;
		end;
		if self.hasAttachedTrailers == 0 then
			setVisibility(self.blinkerLeuchte1R, false);
			setVisibility(self.blinkerLeuchte2R, false);
			setVisibility(self.blinkerLeuchte1L, false);
			setVisibility(self.blinkerLeuchte2L, false);
		elseif self.hasAttachedTrailers == 1 then
			setVisibility(self.blinkerLeuchte1R, true);
			setVisibility(self.blinkerLeuchte2R, false);	
			setVisibility(self.blinkerLeuchte1L, true);
			setVisibility(self.blinkerLeuchte2L, false);			
		elseif self.hasAttachedTrailers == 2 then
			setVisibility(self.blinkerLeuchte1R, true);
			setVisibility(self.blinkerLeuchte2R, true);
			setVisibility(self.blinkerLeuchte1L, true);
			setVisibility(self.blinkerLeuchte2L, true);
		end;
	end;
	-- Animierter Blinkerhebel
	if self.B3.dirLeft[1].a or self.B3.dirRight[1].a or self.B3.wl then
		if self.B3.dirLeft[1].a then
			setRotation(self.blinkerHebel, 0, Utils.degToRad(self.blinkerHebelLeftRot), 0)
		else
			setRotation(self.blinkerHebel, 0, Utils.degToRad(self.blinkerHebelRightRot), 0)
		end;
		if self.B3.wl then
			setRotation(self.blinkerHebel, 0, 0, 0)
		end;
	else
		setRotation(self.blinkerHebel, 0, 0, 0)
	end;
end;
function Fendt310Animations:update(dt)
	if self:getIsActive() then
		-- Uhr / clock
		local clockTime = g_currentMission.environment.dayTime;
		local gr = clockTime / 10000;
		local kl = clockTime / 120000;
		setRotation(self.uhrZeigerKlein, 0, math.rad(-kl), 0);
		setRotation(self.uhrZeigerGross, 0, math.rad(-gr), 0);
		
		if self.realAWDModeOn then
			setTranslation(self.allradHebel, 0, self.allradHebelMaxTrans, 0);
		else
			setTranslation(self.allradHebel, 0, 0, 0);
		end;
		--if self.vehicle ~= nil then
		--	for k, implement in pairs(self.vehicle.attachedImplements) do
		--		if implement.object ~= nil then
		--			if implement.object.isTurnedOn ~= nil then
		--				if implement.object.isTurnedOn then
		if self.realCurrentTotalPowerConsumption > 0 then
			setRotation(self.zapfwelle, Utils.degToRad(self.zapfwelleMaxRot), 0, 0);
		else
			setRotation(self.zapfwelle, 0, 0, 0);
		end;
	end;
end;
function Fendt310Animations:draw()
end;
function Fendt310Animations:onEnter()
end;
function Fendt310Animations:onLeave()
end;

