--
-- WarningSigns
--
-- written by fruktor, visit: www.eifok-team.de
--
-- changed to TwinWheels for Fendt Farmer 310 LSA

TwinWheels = {};

TwinWheels.modDir = g_currentModDirectory;

function TwinWheels.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function TwinWheels:load(xmlFile)
	
	self.playerCallbackTwin = SpecializationUtil.callSpecializationsFunction("playerCallbackTwin"); 
	self.setTwin = SpecializationUtil.callSpecializationsFunction("setTwin"); 
	
	self.tw = {};
	
	local i=0;
	while true do
		local str = getXMLString(xmlFile, string.format("vehicle.TwinWheels.wheel(%d)#index", i));
		if str == nil then
			break;
		end;
		local node = Utils.indexToObject(self.components, str);
		if node == nil then
			print("[Error::TwinWheels] node for "..tostring(str).." does not exist");
			break;
		end;
		local trigger = Utils.indexToObject( self.components, getXMLString(xmlFile, string.format("vehicle.TwinWheels.wheel(%d)#trigger", i)) );
		if trigger == nil then
			print("[Error::TwinWheels] node is OK, but trigger could not be located. Check line "..tostring(i+1).." in your vehicle.xml");
		end;
		local isVis = getXMLBool(xmlFile, string.format("vehicle.TwinWheels.wheel(%d)#isVisible", i))
		self.tw[i+1] = {};
		self.tw[i+1].node = node;
		self.tw[i+1].trigger = trigger;
		self.tw[i+1].isVis = isVis;
		self.tw[i+1].plIR = false;
		
		addTrigger( trigger, "playerCallbackTwin", self );	
		i = i + 1;
	end;
	
end;

function TwinWheels:delete()
	for i,j in pairs(self.tw) do
		if j.trigger ~= nil then
			removeTrigger(j.trigger);
		end;
	end;
end;

function TwinWheels:readStream(streamId, connection)
	for i,j in pairs(self.tw) do
		local state = streamReadBool(streamId);
		self:setTwin(i, state, true);
	end;
end;

function TwinWheels:writeStream(streamId, connection)
	for i,j in pairs(self.tw) do
		streamWriteBool(streamId, j.isVis);
	end;
end;


function TwinWheels:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if not resetVehicles then
		for i,j in pairs(self.tw) do
			local s = Utils.getNoNil( getXMLBool(xmlFile, key..string.format("#twinWheel%d",i) ), false);
			self:setTwin(i, s, true);
		end;
	end; 
    return BaseMission.VEHICLE_LOAD_OK;
end;

function TwinWheels:getSaveAttributesAndNodes(nodeIdent)	
    local attributes = '';
	for i,j in pairs(self.tw) do
		attributes = attributes .. string.format('twinWheel%d="%s" ', i, tostring(j.isVis));
	end;
    return attributes, nil;
end;

function TwinWheels:mouseEvent(posX, posY, isDown, isUp, button)
end;

function TwinWheels:keyEvent(unicode, sym, modifier, isDown)
end;

function TwinWheels:update(dt)
	local plIR = false;
	local id = 0;
	for i,j in pairs(self.tw) do
		if j.plIR then
			id = i;
			plIR = true;
			break;
		end;
	end;
	if self.tw[1].isVis and not self.tw[2].isVis then
		self.realTyreGripFx = 1.5;
	elseif self.tw[2].isVis and not self.tw[1].isVis then
		self.realTyreGripFx = 1.5;
	elseif self.tw[1].isVis and self.tw[2].isVis then
		self.realTyreGripFx = 1.8;
	elseif not self.tw[1].isVis and not self.tw[2].isVis then
		self.realTyreGripFx = 1.25;
	end;
	
	if plIR then
		g_currentMission:addHelpButtonText( g_i18n:getText("SET_TWINWHEEL"), InputBinding.SET_TWINWHEEL );	
		--renderText( g_currentMission.hudAttachmentOverlay.x-0.01, g_currentMission.hudAttachmentOverlay.y, 0.02, g_i18n:getText("SHOW_WARNING_SIGN") );
		setTextColor(1.0, 1.0, 1.0, 1.0);
		setTextAlignment(RenderText.ALIGN_LEFT); 		
		renderText(0.5, 0.09, 0.02, g_i18n:getText("SET_TWINWHEEL") );
		if InputBinding.hasEvent(InputBinding.SET_TWINWHEEL)then
			self:setTwin(id, not self.tw[id].isVis);
		end
	end;
end;

function TwinWheels:onLeave()
end;

function TwinWheels:draw()
end;

function TwinWheels:playerCallbackTwin(triggerId, otherId, onEnter, onLeave, onStay)
--print("function TwinWheels:playerCallbackTwin("..tostring(triggerId)..", "..tostring(otherId)..", "..tostring(onEnter)..", "..tostring(onLeave)..", "..tostring(onStay));
	
	local id = 0;
	for i,j in pairs(self.tw) do
		if j.trigger == triggerId then
			id = i;
			break;
		end;
	end;
	
	if id ~= 0 then
		if onEnter and g_currentMission.controlPlayer and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
			self.tw[id].plIR = true;
		elseif onLeave then
			self.tw[id].plIR = false;
		end;
	end
	
end;


function TwinWheels:setTwin(id, state, noEventSend)
--print("function TwinWheels:setTwin("..tostring(id)..", "..tostring(state)..", "..tostring(noEventSend));
	setTwinEvent.sendEvent(self, id, state, noEventSend);
	self.tw[id].isVis = state;
	setVisibility(self.tw[id].node, state);
end;




-- setTwinEvent
setTwinEvent = {};
setTwinEvent_mt = Class(setTwinEvent, Event);

InitEventClass(setTwinEvent, "setTwinEvent");

function setTwinEvent:emptyNew()
    local self = Event:new(setTwinEvent_mt);
    self.className="setTwinEvent";
    return self;
end;

function setTwinEvent:new(object, id, state)
    local self = setTwinEvent:emptyNew()
    self.object = object;
	self.id = id;
	self.state = state;
    return self;
end;

function setTwinEvent:readStream(streamId, connection)
    local id = streamReadInt32(streamId);
    self.object = networkGetObject(id);
	self.id = streamReadInt32(streamId);
	self.state = streamReadBool(streamId);
    self:run(connection);
end;

function setTwinEvent:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.object));
	streamWriteInt32(streamId, self.id);
	streamWriteBool(streamId, self.state);
end;

function setTwinEvent:run(connection)
    self.object:setTwin(self.id, self.state, true);
    if not connection:getIsServer() then
        g_server:broadcastEvent(setTwinEvent:new(self.object, self.id, self.state), nil, connection, self.object);
    end;
end;

function setTwinEvent.sendEvent(vehicle, id, state, noEventSend)
	if noEventSend == nil or noEventSend == false then
		if g_server ~= nil then
			g_server:broadcastEvent(setTwinEvent:new(vehicle, id, state), nil, nil, vehicle);
		else
			g_client:getServerConnection():sendEvent(setTwinEvent:new(vehicle, id, state));
		end;
	end;
end;

